# Change Log
All notable changes to this project will be documented in this file.

## [0.1.3] - 2021-11-23

Fix a minor bug discovered after the last release and work on improve unitary tests.

### Added

- More unitary tests.
- Compatibility test for Python 3.10.
- Method to get the market date as datetime on PvpcMarket object.
 
### Fixed

- Minor bug fix on markets module, caused by sort the original prices list.


## [0.1.2] - 2021-11-22
 
Add this changelog file for tracking notable changes.
Some fixes on CI/CD pipeline and documentation generator.
New minimal functionalities.
 
### Added

- Changelog file.
  
- Calculation of the average price of the market session.

- Indication if price is below average price of the market session.
 

### Fixed
 
- Fix documentation auto generation.